# encoding: utf-8
#
# Copyright (C) 2021 willipink.eu
# Author Moritz Münch moritzmuench@mailbox.org
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


from django.http import HttpResponse
from django.test import TestCase, Client

from coinc.models import Coin, Country
from coinc.views import add_coin
from coinc.helper import get_test_response_status


class TestCoin(TestCase):

    ''' all tests for the coin model '''
    def setUp(self):
        self.test_post_data = {
            'value': 1,
            'year': 2050,
            'country': 'fo',
            'stamp': '',
            'exists': 'false',
            'name': '',
            'found_by': '',
            'found_on': '03.05.2040',
    #                 'date-added' '':,
    #                 'date-modified':,
            'circulation': 0,
            'bux_only': 'false',
            'checked': 'false',
            'ec': 'false'
        }
        Country.objects.create(
            name_iso = 'fo',
            name = 'bar'
        )

    def _return_status_wrong_field(self, field, data):
        ''' shortcut: return response status of post request to /coinc/add/coin '''

        test_data = self.test_post_data
        test_data[field] = data
        test_response = self.client.post(f'/coinc/add/coin', test_data)
        return get_test_response_status(test_response)


    def test_view_add_coin_missing_post_values(self):

        # all values right
        self.assertEqual(self._return_status_wrong_field('value', '1'), 0)

        # value not a number
        self.assertEqual(self._return_status_wrong_field('value', ''), 1)
        # value not the right number
        self.assertEqual(self._return_status_wrong_field('value', 3), 1)

        # year not a number
        self.assertEqual(self._return_status_wrong_field('year', ''), 1)
        # year lower limit
        self.assertEqual(self._return_status_wrong_field('year', 1998), 1)
        # year upper limit
        self.assertEqual(self._return_status_wrong_field('year', 2099), 1)

        # country not valid format xx
        self.assertEqual(self._return_status_wrong_field('country', 12235235), 1)
        self.assertEqual(self._return_status_wrong_field('country', 'toolong'), 1)
        # country does not exist
        self.assertEqual(self._return_status_wrong_field('country', 'xx'), 1)

        #stamp does not exist
        self.assertEqual(self._return_status_wrong_field('stamp', 'xx'), 1)
        self.assertEqual(self._return_status_wrong_field('stamp', 'longer than 10 characters'), 1)
        self.assertEqual(self._return_status_wrong_field('stamp', 'xx'), 1)


    def test_views_add_without_year(self):
        pass
