# encoding: utf-8
#
# Copyright (C) 2021 willipink.eu
# Author Moritz Münch moritzmuench@mailbox.org
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


from json import loads

from django.http import HttpResponse
from django.test import TestCase, Client

from coinc.models import User
from coinc.views import add_user


class TestUser(TestCase):

    ''' all test for the user model '''
    def setUp(self):
        self.test_username = 'test_username'
        self.test_color = 'test_color'
        self.test_request = 'test_request'


    def test_urls_add_without_username(self):
        ''' url: test adding a user without username '''
        test_response = self.client.get(
            f'/coinc/add/user//color/{self.test_color}')
        self.assertEqual(test_response.status_code, 404)


        test_response = self.client.get(
            f'/coinc/add/user/color/{self.test_color}')
        self.assertEqual(test_response.status_code, 404)


        test_response = self.client.get(
            f'/coinc/add/color/{self.test_color}')
        self.assertEqual(test_response.status_code, 404)


    def test_urls_add_without_color(self):
        ''' url: test adding a user without color '''
        test_response = self.client.get(
            f'/coinc/add/user/{self.test_username}/color')
        self.assertEqual(test_response.status_code, 404)

        test_response = self.client.get(
            f'/coinc/add/user/{self.test_username}')
        self.assertEqual(test_response.status_code, 404)


    def test_urls_add_without_username_and_color(self):
        ''' url: test adding a user without username and color '''
        test_response = self.client.get(
            f'/coinc/add/user//color')
        self.assertEqual(test_response.status_code, 404)


        test_response = self.client.get(
            f'/coinc/add/user/color')
        self.assertEqual(test_response.status_code, 404)


        test_response = self.client.get(
            f'/coinc/add/user')
        self.assertEqual(test_response.status_code, 404)


    def test_urls_add_not_existing_user(self):
        ''' url: test adding a user which does not yet exist '''

        test_response = self.client.get(
            f'/coinc/add/user/{self.test_username}/color/{self.test_color}')
        self.assertEqual(test_response.status_code, 200)


    def test_view_add_not_existing_user(self):
        ''' view: test adding a user which does not yet exist '''

        test_response = add_user(self.test_request, self.test_username,
                self.test_color)
        test_status = loads(test_response.content)
        test_status = test_status['status']
        self.assertEqual(test_status, 0)


    def test_add_existing_user(self):
        ''' view: test adding a user twice '''

        # first user
        test_response = self.client.get(
            f'/coinc/add/user/{self.test_username}/color/{self.test_color}')
        test_status = loads(test_response.content)
        test_status = test_status['status']
        self.assertEqual(test_status, 0)

        # second user
        test_response = self.client.get(
            f'/coinc/add/user/{self.test_username}/color/{self.test_color}')
        test_status = loads(test_response.content)
        test_status = test_status['status']
        self.assertEqual(test_status, 1)
